@@ -1,6 +1,6 @@
 package Email::Sender::Transport::Redirect;
 {
-    $Email::Sender::Transport::Redirect::VERSION = '0.0002';
+    $Email::Sender::Transport::Redirect::VERSION = '0.0003';
 }
 
 =head1 NAME
@@ -9,7 +9,7 @@ Email::Sender::Transport::Redirect - Intercept all emails and redirect them to a
 
 =head1 VERSION
 
-Version 0.0002
+Version 0.0003
 
 =head1 SYNOPSIS
 
@@ -28,6 +28,31 @@ This transport changes the C<To> and C<CC> header in the email and
 adds a C<X-Intercepted-To> and C<X-Intercepted-CC> header with
 the original recipients.
 
+=head1 ATTRIBUTES
+
+=head2 redirect_address
+
+Recipient email address for redirected emails.
+
+=head2 redirect_headers
+
+Email headers to be changed, defaults to an
+array reference containing:
+
+=over 4
+
+=item To
+
+=item CC
+
+=back
+
+=head2 intercept_prefix
+
+Prefix for headers which show the original recipients.
+
+Defaults to C<X-Intercepted->.
+
 =cut
 
 use Moo;
@@ -51,6 +76,14 @@ has 'intercept_prefix' => (
                            default => 'X-Intercepted-',
                           );
 
+=head1 METHOD MODIFIERS
+
+=head2 send_email
+
+Wraps around original method and changes email headers.
+
+=cut
+
 around send_email => sub {
     my ($orig, $self, $email, $env, @rest) = @_;
     my ($email_copy, $env_copy, @values);
@@ -82,42 +115,6 @@ around send_email => sub {
 
 Stefan Hornburg (Racke), C<racke@linuxia.de>
 
-=head1 BUGS
-
-Please report any bugs or feature requests to C<bug-email-sender-transport-redirect at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Email-Sender-Transport-Redirect>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
-
-=head1 SUPPORT
-
-You can find documentation for this module with the perldoc command.
-
-    perldoc Email::Sender::Transport::Redirect
-
-
-You can also look for information at:
-
-=over 4
-
-=item * RT: CPAN's request tracker (report bugs here)
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Email-Sender-Transport-Redirect>
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/Email-Sender-Transport-Redirect>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/Email-Sender-Transport-Redirect>
-
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/Email-Sender-Transport-Redirect/>
-
-=back
-
-
 =head1 ACKNOWLEDGEMENTS
 
 Thanks to Peter Mottram for the port to Moo (GH #1).
